@@ -7,8 +7,6 @@ use grpc_plugins::grpc_controller_server::{GrpcController, GrpcControllerServer}
 use grpc_plugins::Empty;
 use tonic::{async_trait, Request, Response, Status};
 
-const LOG_PREFIX: &str = "GrrPlugin::GrpcController: ";
-
 pub fn new_server(trigger: triggered::Trigger) -> GrpcControllerServer<GrpcControllerImpl> {
     GrpcControllerServer::new(GrpcControllerImpl { trigger })
 }
@@ -21,7 +19,7 @@ pub struct GrpcControllerImpl {
 #[async_trait]
 impl GrpcController for GrpcControllerImpl {
     async fn shutdown(&self, _req: Request<Empty>) -> Result<Response<Empty>, Status> {
-        log::info!("{} shutdown called. Stopping grpc server...", LOG_PREFIX);
+        log::info!("shutdown called. Stopping grpc server...");
 
         self.trigger.trigger();
         Ok(Response::new(Empty {}))
